==> haskell-case-insensitive-1.2.1.0-131-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 case-insensitive
version:              1.2.1.0
visibility:           public
id:                   case-insensitive-1.2.1.0-7tlHjdA9EMW5qmWLHd5fW4
key:                  case-insensitive-1.2.1.0-7tlHjdA9EMW5qmWLHd5fW4
license:              BSD-3-Clause
copyright:            2011 Bas van Dijk
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk
homepage:             https://github.com/basvandijk/case-insensitive
synopsis:             Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.

category:             Data, Text
abi:                  bacd5f78e13ae50785135c761abe035a
exposed:              True
exposed-modules:      Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules:       Data.CaseInsensitive.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/case-insensitive-1.2.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/case-insensitive-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/case-insensitive-1.2.1.0
hs-libraries:         HScase-insensitive-1.2.1.0-7tlHjdA9EMW5qmWLHd5fW4
depends:
    base-4.15.1.0 bytestring-0.10.12.1 deepseq-1.4.5.0
    hashable-1.4.0.0-C2L4d9qsiUqGAQXABPs7JE text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock

haddock-html:         /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-case-insensitive-1.2.1.0-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 case-insensitive
version:              1.2.1.0
visibility:           public
id:                   case-insensitive-1.2.1.0-CRT7ZECRUzxCm9b8jdp7qY
key:                  case-insensitive-1.2.1.0-CRT7ZECRUzxCm9b8jdp7qY
license:              BSD-3-Clause
copyright:            2011 Bas van Dijk
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk
homepage:             https://github.com/basvandijk/case-insensitive
synopsis:             Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.

category:             Data, Text
abi:                  8f287859e1b721f3367a6b4c1c0192dd
exposed:              True
exposed-modules:      Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules:       Data.CaseInsensitive.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/case-insensitive-1.2.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/case-insensitive-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/case-insensitive-1.2.1.0
hs-libraries:         HScase-insensitive-1.2.1.0-CRT7ZECRUzxCm9b8jdp7qY
depends:
    base-4.15.1.0 bytestring-0.10.12.1 deepseq-1.4.5.0
    hashable-1.4.0.0-LbiCNO5gyl3FzQI198nxBm text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock

haddock-html:         /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
